function [ cleDrawDat, width ] = gphPolygonPrintf(x,y,typeFace,height,alignment,format,varargin)
%gphPolygonPrintf    - Print formatted text.
%
%   [cleDrawDat, width] = gphPolygonPrintf(x, y, typeFace, height, alignment, format, ...)
%       x           - Text x position.
%       y           - Text y position.
%       typeFace    - Font type.
%       height      - Font height in microns.
%       alignment   - 'l' left aligned.
%                     'r' right aligned.
%                     'c' centre aligned.
%       format      - String containing C language conversion
%                     specleications.
%    
%       width       - Width of text string.
%       cleDrawDat  - Optional output structure for further editing.
%                     If not used, data is directly writen to .cle file.

global CleWin;

if (~isnumeric(x) | ~isnumeric(y) | ~isstr(typeFace) | ~isnumeric(height) | ...
    ~isstr(alignment) | length(alignment)~=1 | ~isstr(format) | ...
    length(x)~=1 | length(y)~=1 )
    error('CleWin:gphPolygonPrintf:InputError', ...
          'Incorrect input parameter(s).');
end;

cleDrawDat=cleEmpty();
%------------------------------------------------------------

[T,X,Y]=gphCorePolygonText(typeFace,sprintf(format,varargin{:}));

X=X*height; Y=(max(Y)-Y)*height;

width=max(X);
if strcmp(alignment,'r')
 X=X-max(X);
elseif strcmp(alignment,'c')
 X=X-0.5*max(X);
end;
   
PlotType=bitand(T,6);
PolygonRange=find(bitand(T,1)==1);

for p=1:length(PlotType)
 if PlotType(p)==4
  PlotType(p+1:p+2)=[ 0 0 ];
 end;
end;

%------------------------------------------------------------
for p=1:(length(PolygonRange)-1)
 cleDrawDat.clePolygon{p}.points=[]; 
 for r=(PolygonRange(p)+1):PolygonRange(p+1)
 
  if PlotType(r)==6  %PT_MOVETO
   TempPolygon=[cleDrawDat.clePolygon{p}.points' [X(r);Y(r)]];
   cleDrawDat.clePolygon{p}.points=TempPolygon';
   cleDrawDat.clePolygon{p}.layer=CleWin.layer;
  end;
  
  if PlotType(r)==2  %PT_LINETO
   TempPolygon=[cleDrawDat.clePolygon{p}.points' [X(r);Y(r)]];
   cleDrawDat.clePolygon{p}.points=TempPolygon';
   cleDrawDat.clePolygon{p}.layer=CleWin.layer;
  end;
    
  if PlotType(r)==4  %PT_BEZIERTO
   BX=X((r-1):(r+2));
   BY=Y((r-1):(r+2));
   %-- Cubic Bezier curve -----------
   bcT=linspace(0,1,4);
   bcX=BX(1)*(1-bcT).^3 + BX(2)*3*(1-bcT).^2.*bcT + ...
       BX(3)*3*(1-bcT).*bcT.^2 + BX(4)*bcT.^3;
   bcY=BY(1)*(1-bcT).^3 + BY(2)*3*(1-bcT).^2.*bcT + ...
       BY(3)*3*(1-bcT).*bcT.^2 + BY(4)*bcT.^3;
   %---------------------------------
   TempPolygon=[cleDrawDat.clePolygon{p}.points' [bcX;bcY]];
   cleDrawDat.clePolygon{p}.points=TempPolygon';
   cleDrawDat.clePolygon{p}.layer=CleWin.layer;
  end;
  
 end;
end;

%-- Substract inside curves from outside curves ----
if length(cleDrawDat.clePolygon)>1
 cleDrawDatA=cleEmpty();
 cleDrawDatB=cleEmpty();

 NrPolygonsA=1;NrPolygonsB=0;
 cleDrawDatA.clePolygon{1}=cleDrawDat.clePolygon{1};
 for p=2:length(cleDrawDat.clePolygon)
  if max(cleDrawDatA.clePolygon{NrPolygonsA}.points(:,1))>max(cleDrawDat.clePolygon{p}.points(:,1)) & ...
     min(cleDrawDatA.clePolygon{NrPolygonsA}.points(:,1))<min(cleDrawDat.clePolygon{p}.points(:,1))     
   NrPolygonsB=NrPolygonsB+1;
   cleDrawDatB.clePolygon{NrPolygonsB}=cleDrawDat.clePolygon{p};
  else
   NrPolygonsA=NrPolygonsA+1;
   cleDrawDatA.clePolygon{NrPolygonsA}=cleDrawDat.clePolygon{p};
  end;
 end;
 
 if NrPolygonsB>0
  cleDrawDat=cleXOR(cleDrawDatA,cleDrawDatB);
 end;
end;

cleDrawDat=cleTranslate(cleDrawDat,[x y]);

%-- Draw cleDrawDat ---------------------------
if nargout < 1,
 cleDraw(cleDrawDat);
end;
%----------------------------------------------

