function [ cleDrawDat ] = sctStripLine(sctDef,stripPos, points, varargin)
%sctStripLine    - Draw strip on SCT Line.
%
%   cleDrawDat = sctLine(sctDef, stripPos, points, roundOfRadius)
%       sctDef           - etc.
%       points           - etc.
%       stripPos         - etc.
%       etc.
%
%       cleDrawDat       - Optional output structure for further editing.
%                          If not used, data is directly writen to CleWin.


% if (~isnumeric(x) | ~isnumeric(y) | ~isnumeric(height) | ~isnumeric(width) | ...
%      length(x)~=1 | length(y)~=1 | length(height)~=1 | length(width)~=1 )
%     error('CleWin:cleBox:InputError', ...
%           'Incorrect input parameter(s).');
% end;

% if nargin>4
%  if (~isnumeric(varargin{1}) |  length(varargin{1})~=1 )
%     error('CleWin:cleBox:InputError', ...
%           'Incorrect input parameter(s).');  
%  end;
% end;

if (size(points,2)~=2)
 points=points';
end;

if (nargin>3)
 roundOfRadius = varargin{1};
else
 roundOfRadius = sctDef.roundOfRadius;
end;

if (sctDef.numberChnls==1) sctDef.seperationChnls=0; end;

cleDrawDat=cleEmpty();
N=size(points,1);

%--- Draw SCT Channels ----------------------------------------------------
anglesStart = sctInternalAngles(points,1);
nodesStart = sctInternalNodes(sctDef,points,1,anglesStart,stripPos);
[sepsStart,cleRndOf] = sctInternalRoundOf(sctDef,stripPos,points,1,nodesStart,...
                                                anglesStart,roundOfRadius);
cleGroup(cleDrawDat,cleRndOf);
for n=2:N,
 anglesEnd = sctInternalAngles(points,n);
 nodesEnd = sctInternalNodes(sctDef,points,n,anglesEnd,stripPos);  
 [sepsEnd,cleRndOf] = sctInternalRoundOf(sctDef,stripPos,points,n,nodesEnd,...
                                                  anglesEnd,roundOfRadius);

 cleDrawDat = cleGroup(cleDrawDat,cleRndOf,sctInternalLine(sctDef,...
                                   nodesStart,nodesEnd,sepsStart,sepsEnd));

 anglesStart = anglesEnd; nodesStart = nodesEnd; sepsStart = sepsEnd;
end;

%--- Draw Markers ---------------------------------------------------------
if (sctDef.placeMarkers==true)
 cleLayer(sctDef.markerLayer); 
 for n=1:N,
  if (n==1 | n==N)
   cleDrawDat=cleGroup(cleDrawDat,cleSubstract(cleConvert(...
                    cleCircle(points(n,1),points(n,2),sctDef.dashLength+...
            sctDef.dashSeperation),15),cleConvert(cleCircle(points(n,1),...
                    points(n,2),sctDef.dashLength+sctDef.dashSeperation-...
                                               0.5*sctDef.dashWidth),15))); 
   angles=sctInternalAngles(points,n);
   cleDrawDat=cleGroup(cleDrawDat,cleBox(points(n,1),points(n,2),...
     0.5*sctDef.dashWidth,(sctDef.numberChnls-1)*sctDef.seperationChnls+...
                   2*sctDef.dashLength+3*sctDef.dashSeperation,angles(4)));
  else
   cleDrawDat=cleGroup(cleDrawDat,cleCircle(points(n,1),points(n,2),...
                                 sctDef.dashLength+sctDef.dashSeperation));
  end;
 end;
end;

%--------------------------------------------------------------------------
if nargout < 1,
 cleDraw(cleDrawDat);
end;


%% -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
function [ seperations,cleDrawDat ] = sctInternalRoundOf(sctDef,stripPos,points,...
                                              n,nodes,angles,roundOfRadius)
if (isnan(angles(1)) | isnan(angles(2)))
 seperations = [0 0];
 cleDrawDat = cleEmpty();
else
 cleDrawDat = cleEmpty();
 roundOfException = false;
       
 if (length(roundOfRadius)==1)
  radius=roundOfRadius;
 else
  radius=roundOfRadius(n-1);  
 end;
 
 sigmaCirc=abs(radius/sin(0.5*angles(3)));
 sigmaIsdCrn=sctDef.seperationChnls*(0.5*sctDef.numberChnls-0.5);
 pointCirc(1)=points(n,1)+cos(angles(5))*(sigmaIsdCrn./...
                        sin(abs(0.5*angles(3)))+sigmaCirc);
 pointCirc(2)=points(n,2)+sin(angles(5))*(sigmaIsdCrn./...
                        sin(abs(0.5*angles(3)))+sigmaCirc);

 %-------------------------------------------------                   
 sigmaCheck=sqrt(abs(pointCirc(1)-points(n,1))^2+abs(pointCirc(2)-...
                                                           points(n,2))^2);                  
 seperationCheck = 2.5*sctDef.dashSeperation+2.5*sctDef.dashLength+...
                                        abs(sigmaCheck*cos(0.5*angles(3))); 
 linePreCheck = sqrt(sum(abs(points(n-1,:)-points(n,:)).^2));
 linePostCheck = sqrt(sum(abs(points(n,:)-points(n+1,:)).^2));
 
 if ((seperationCheck>0.5*linePreCheck | seperationCheck>0.5*linePostCheck)&(n~=length(points)-1)&(n~=2))
  roundOfException = true;
 end;
 
 if ((seperationCheck>linePreCheck | seperationCheck>linePostCheck)&((n==length(points)-1)|(n==2)))
  roundOfException = true;
 end;
 
 if (floor((abs(pi-abs(angles(3))-(sctDef.dashSeperation+sctDef.dashLength)/(pi*radius))*radius)/...
         (sctDef.dashSeperation+sctDef.dashLength))<5)
  roundOfException =true;
 end;
 
 %-------------------------------------------------
                        
 if (roundOfException==false),
  for m=1:2,                         
   sigma=sqrt(abs(pointCirc(1)-nodes(m,1))^2+abs(pointCirc(2)-...
                                                            nodes(m,2))^2);
 
   if (sqrt(sum((pointCirc-points(n,:)).^2))<sqrt(sum((nodes(m,:)-points(n,:)).^2)) & abs(angle((pointCirc-points(n,:))*[1; i])-angle((nodes(m,:)-points(n,:))*[1; i]))<0.1 ), sigma=0; end;
   r=sigma*abs(sin(0.5*angles(3)));
  
   thetaStart=angles(5)+0.5*pi+0.5*abs(angles(3));
   thetaEnd  =angles(5)+1.5*pi-0.5*abs(angles(3));
 
   nThetaSteps = 2*ceil((abs(thetaEnd-thetaStart)*r)/...
                            (sctDef.dashSeperation+sctDef.dashLength));
   thetaSteps = linspace(thetaStart,thetaEnd,nThetaSteps);

   if (sigma~=0),
    roundOf{m}= [pointCirc(1)+r*cos(thetaSteps); pointCirc(2)+r*sin(thetaSteps)];
   else,
    roundOf{m}= nodes(m,:)';
   end;
   seperations(m) = abs(sigma*cos(0.5*angles(3)));
  end;
  cleLayer(sctDef.stripLayer);
  cleDrawDat=clePolygon([roundOf{1} fliplr(roundOf{2})]);
 end;
 
 if (roundOfException==true),
  linePos = sctDef.seperationChnls.*((1:sctDef.numberChnls)-0.5*sctDef.numberChnls-0.5);
  
  [stripProxA,chnlA]=min(abs(linePos-stripPos(1)));
  [stripProxB,chnlB]=min(abs(linePos-stripPos(2)));
  if (linePos(chnlA)<stripPos(1) & linePos(chnlB)<stripPos(2) & chnlA~=chnlB), chnlA=chnlA+1; stripProxA=abs(linePos(chnlA)-stripPos(1)); end;
  if (linePos(chnlB)>stripPos(2) & linePos(chnlA)>stripPos(1) & chnlA~=chnlB), chnlB=chnlB-1; stripProxB=abs(linePos(chnlB)-stripPos(2)); end;
  
  signA=sign(chnlA-0.5*sctDef.numberChnls-0.1);
  signB=sign(chnlB-0.5*sctDef.numberChnls-0.1);
  lineSecA = abs((sctDef.seperationChnls.*(chnlA-0.5*sctDef.numberChnls-0.5))/sin(0.5*angles(3)))+signA*(0.5*sctDef.dashLength)/tan(0.5*angles(3));
  lineSecB = abs((sctDef.seperationChnls.*(chnlB-0.5*sctDef.numberChnls-0.5))/sin(0.5*angles(3)))+signB*(0.5*sctDef.dashLength)/tan(0.5*angles(3));
  linePointA = [points(n,1)-signA*lineSecA*cos(angles(4)) points(n,2)-signA*lineSecA*sin(angles(4))];
  linePointB = [points(n,1)-signB*lineSecB*cos(angles(4)) points(n,2)-signB*lineSecB*sin(angles(4))];
  
  signAE=1-2*(abs(angles(5)-angle([1 i]*(linePointA-nodes(1,:))'))<0.1 & (stripPos(1)-linePos(chnlA))<0 & angles(4)==angles(5));
  signBE=1-2*(abs(angles(5)-angle([1 i]*(linePointB-nodes(2,:))'))<0.1 & (stripPos(2)-linePos(chnlB))>0 & angles(4)~=angles(5));
  sepStripA=sqrt(sum((linePointA-nodes(1,:)).^2))-signAE*stripProxA;
  sepStripB=sqrt(sum((linePointB-nodes(2,:)).^2))-signBE*stripProxB;
  if (sqrt(sum((linePointA-nodes(1,:)).^2)) > abs(stripProxA) & abs(angles(5)-angle([1 i]*(nodes(1,:)-linePointA)'))<0.1 ) sepStripA=0; end;
  if (sqrt(sum((linePointB-nodes(2,:)).^2)) > abs(stripProxB) & abs(angles(5)-angle([1 i]*(nodes(2,:)-linePointB)'))<0.1 ) sepStripB=0; end;
   
  seperations = [abs(sepStripA)/cos(0.5*angles(3)) abs(sepStripB)/cos(0.5*angles(3))];
  
  cleLayer(sctDef.stripLayer);
  cleDrawDat=clePolygon([nodes(1,1)+seperations(1)*cos(angles(1)) nodes(1,2)+seperations(1)*sin(angles(1)); ...
                      nodes(2,1)+seperations(2)*cos(angles(1)) nodes(2,2)+seperations(2)*sin(angles(1)); ...
                      nodes(2,1)+seperations(2)*cos(angles(2)) nodes(2,2)+seperations(2)*sin(angles(2)); ...
                      nodes(1,1)+seperations(1)*cos(angles(2)) nodes(1,2)+seperations(1)*sin(angles(2))]);  
 end;
 
end;

%% -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
function [ angles ] = sctInternalAngles(points,n)
N=size(points,1);
if (n==1)
 angles(1)=NaN;
 angles(2)=angle( (points(n+1,1)-points(n,1))+...
                                           i*(points(n+1,2)-points(n,2)) );
 angles(3)=pi;
 angles(4)=angles(2)-0.5*pi;
 angles(5)=NaN;
elseif (n==N)
 angles(1)=angle( (points(n-1,1)-points(n,1))+...
                                           i*(points(n-1,2)-points(n,2)) );
 angles(2)=NaN;
 angles(3)=pi;
 angles(4)=angles(1)+0.5*pi;
 angles(5)=NaN;
else
 angles(1)=angle( (points(n-1,1)-points(n,1))+...
                                           i*(points(n-1,2)-points(n,2)) );
 angles(2)=angle( (points(n+1,1)-points(n,1))+...
                                           i*(points(n+1,2)-points(n,2)) );
 angles(3)=angles(1)-angles(2);
 angles(3)=angles(3)-sign(angles(3))*(abs(angles(3))>(pi))*2*pi;
 if (angles(3)<=0)
  angles(4)=angles(2)+0.5*angles(3);
 else
  angles(4)=angles(2)+pi+0.5*angles(3);
  angles(4)=angles(4)-sign(angles(4))*(abs(angles(4))>(pi))*2*pi;
 end;
 angles(5)=0.5*angles(3)+angles(2);
end;

%% -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
function [ nodes ] = sctInternalNodes(sctDef,points,n,angles,stripPos)
nodes(1,1)=points(n,1)+cos(angles(4)).*(-min(stripPos)./sin(abs(0.5*angles(3))));
nodes(1,2)=points(n,2)+sin(angles(4)).*(-min(stripPos)./sin(abs(0.5*angles(3))));
nodes(2,1)=points(n,1)+cos(angles(4)).*(-max(stripPos)./sin(abs(0.5*angles(3))));
nodes(2,2)=points(n,2)+sin(angles(4)).*(-max(stripPos)./sin(abs(0.5*angles(3)))); 

%% -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
function [ cleDrawDat ] = sctInternalLine(sctDef,nodesStart,nodesEnd,...
                                                         sepsStart,sepsEnd)
theta = angle( (nodesEnd(1,1)-nodesStart(1,1))+...
                                       i*(nodesEnd(1,2)-nodesStart(1,2)) );
cleLayer(sctDef.stripLayer);
cleDrawDat=clePolygon([nodesStart(1,1)+sepsStart(1)*cos(theta) nodesStart(1,2)+sepsStart(1)*sin(theta); ...
                       nodesStart(2,1)+sepsStart(2)*cos(theta) nodesStart(2,2)+sepsStart(2)*sin(theta); ...
                       nodesEnd(2,1)-sepsEnd(2)*cos(theta) nodesEnd(2,2)-sepsEnd(2)*sin(theta); ...
                       nodesEnd(1,1)-sepsEnd(1)*cos(theta) nodesEnd(1,2)-sepsEnd(1)*sin(theta)]);